webui

package
v0.1.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 14, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var WebUIFiles embed.FS

Embed all webui dist files The embed path is relative to this package directory Files are copied here during build

Functions

This section is empty.

Types

type GenerateRequest

type GenerateRequest struct {
	IDL     string `json:"idl"`
	Runtime string `json:"runtime"`
}

GenerateRequest represents the request body for /api/playground/generate

type GenerateResponse

type GenerateResponse struct {
	ID    string   `json:"id"`
	Files []string `json:"files"`
}

GenerateResponse represents the response from /api/playground/generate

type Server

type Server struct {
	// contains filtered or unexported fields
}

Server represents the web UI HTTP server

func NewServer

func NewServer(port int) *Server

NewServer creates a new web UI server

func (*Server) Start

func (s *Server) Start() error

Start starts the HTTP server

Jump to