Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var WebUIFiles embed.FS
Embed all webui dist files The embed path is relative to this package directory Files are copied here during build
Functions ¶
This section is empty.
Types ¶
type GenerateRequest ¶
GenerateRequest represents the request body for /api/playground/generate
type GenerateResponse ¶
GenerateResponse represents the response from /api/playground/generate
Click to show internal directories.
Click to hide internal directories.